@@ -18,11 +18,11 @@ Mojo::Pg::Che - mix of parent Mojo::Pg and DBI.pm
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 
 =head1 SYNOPSIS
@@ -171,6 +171,11 @@ DBI style quering. See L<DBI#selectcol_arrayref>. Blocking|non-blocking, query s
 
 DBI style quering. See L<DBI#do>. Blocking|non-blocking, query string|statement handler.
 
+=head2 begin
+
+Start transaction and return new <Mojo::Pg::Che::Database> object which attr C< {tx} > is a <Mojo::Pg::Transaction> object. Sinonyms are: C<< ->tx >> and C<< ->begin_work >>.
+
+
 =head1 AUTHOR
 
 Михаил Че (Mikhail Che), C<< <mche[-at-]cpan.org> >>
